summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmdiscedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmdiscedit.h')
-rw-r--r--kpovmodeler/pmdiscedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmdiscedit.h b/kpovmodeler/pmdiscedit.h
index 73466f32..2741c1df 100644
--- a/kpovmodeler/pmdiscedit.h
+++ b/kpovmodeler/pmdiscedit.h
@@ -37,9 +37,9 @@ class PMDiscEdit : public PMGraphicalObjectEdit
typedef PMGraphicalObjectEdit Base;
public:
/**
* Creates a PMPlaneEdit with tqparent and name
*/
- PMDiscEdit( TQWidget* tqparent, const char* name = 0 );
+ PMDiscEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -37,9 +37,9 @@ class PMDiscEdit : public PMGraphicalObjectEdit
public:
/**
- * Creates a PMPlaneEdit with tqparent and name
+ * Creates a PMPlaneEdit with parent and name
*/